xclim package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xclim.core
   xclim.indicators
   xclim.indices
   xclim.locales
   xclim.sdba
   xclim.testing

Submodules
----------

xclim.cli module
----------------

.. automodule:: xclim.cli
   :members:
   :undoc-members:
   :show-inheritance:

xclim.ensembles module
----------------------

.. automodule:: xclim.ensembles
   :members:
   :undoc-members:
   :show-inheritance:

xclim.subset module
-------------------

.. automodule:: xclim.subset
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: xclim
   :members:
   :undoc-members:
   :show-inheritance:
